import { notLoggedInValidator, hasPersonValidator } from "aleksis.core/routeValidators";

export default
  {
    meta: {
      inMenu: true,
      titleKey: "alsijil.menu_title",
      icon: "mdi-account-group-outline",
      validators: [
        hasPersonValidator
      ]
    },
    children: [
      {
        path: "coursebook/:lessonId(\\d+)/",
        component: () => import("./components/coursebook/CourseBook.vue"),
        props: true,
        name: "alsijil.courseBookByID",
      },
      {
        path: "coursebook/",
        component: () => import("./components/coursebook/CourseBookList.vue"),
        name: "alsijil.courseBookList",
        meta: {
          inMenu: true,
          titleKey: "alsijil.coursebook.menu_title",
          icon: "mdi-book-education-outline",
          permission: "alsijil.view_coursebook_rule",
        },
      },
      {
        path: "lesson",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.lessonPeriod",
        meta: {
          inMenu: true,
          titleKey: "alsijil.lesson.menu_title",
          icon: "mdi-alarm",
          permission: "alsijil.view_lesson_menu_rule",
        },
      },
      {
        path: "lesson/:year(\\d+)/:week(\\d+)/:id_(\\d+)",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.lessonPeriodByCWAndID",
      },
      {
        path: "extra_lesson/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.extraLessonByID",
      },
      {
        path: "event/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.eventByID",
      },
      {
        path: "week/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.weekView",
        meta: {
          inMenu: true,
          titleKey: "alsijil.week.menu_title",
          icon: "mdi-view-week-outline",
          permission: "alsijil.view_week_menu_rule",
        },
      },
      {
        path: "week/:year(\\d+)/:week(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.weekViewByWeek",
      },
      {
        path: "week/year/cw/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.weekViewPlaceholders",
      },
      {
        path: "week/:type_/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.weekViewByTypeAndID",
      },
      {
        path: "week/year/cw/:type_/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.weekViewPlaceholdersByTypeAndID",
      },
      {
        path: "week/:year(\\d+)/:week(\\d+)/:type_/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.weekViewByWeekTypeAndID",
      },
      {
        path: "print/group/:id_(\\d+)",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.fullRegisterGroup",
      },
      {
        path: "groups/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.myGroups",
        meta: {
          inMenu: true,
          titleKey: "alsijil.groups.menu_title",
          icon: "mdi-account-multiple-outline",
          permission: "alsijil.view_my_groups_rule",
        },
      },
      {
        path: "groups/:pk(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.studentsList",
      },
      {
        path: "persons/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.myStudents",
        meta: {
          inMenu: true,
          titleKey: "alsijil.persons.menu_title",
          icon: "mdi-account-school-outline",
          permission: "alsijil.view_my_students_rule",
        },
      },
      {
        path: "persons/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.overviewPerson",
      },
      {
        path: "me/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.overviewMe",
        meta: {
          inMenu: true,
          titleKey: "alsijil.my_overview.menu_title",
          icon: "mdi-chart-box-outline",
          permission: "alsijil.view_person_overview_menu_rule",
        },
      },
      {
        path: "notes/:pk(\\d+)/delete/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.deletePersonalNote",
      },
      {
        path: "absence/new/:id_(\\d+)/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.registerAbsenceWithID",
      },
      {
        path: "absence/new/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.registerAbsence",
        meta: {
          inMenu: true,
          titleKey: "alsijil.absence.menu_title",
          icon: "mdi-message-draw",
          permission: "alsijil.view_register_absence_rule",
        },
      },
      {
        path: "extra_marks/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.extraMarks",
        meta: {
          inMenu: true,
          titleKey: "alsijil.extra_marks.menu_title",
          icon: "mdi-label-variant-outline",
          permission: "alsijil.view_extramarks_rule",
        },
      },
      {
        path: "extra_marks/create/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.createExtraMark",
      },
      {
        path: "extra_marks/:pk(\\d+)/edit/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.editExtraMark",
      },
      {
        path: "extra_marks/:pk(\\d+)/delete/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.deleteExtraMark",
      },
      {
        path: "excuse_types/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.excuseTypes",
        meta: {
          inMenu: true,
          titleKey: "alsijil.excuse_types.menu_title",
          icon: "mdi-label-outline",
          permission: "alsijil.view_excusetypes_rule",
        },
      },
      {
        path: "excuse_types/create/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.createExcuseType",
      },
      {
        path: "excuse_types/:pk(\\d+)/edit/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.editExcuseType",
      },
      {
        path: "excuse_types/:pk(\\d+)/delete/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.deleteExcuseType",
      },
      {
        path: "group_roles/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.groupRoles",
        meta: {
          inMenu: true,
          titleKey: "alsijil.group_roles.menu_title_manage",
          icon: "mdi-clipboard-plus-outline",
          permission: "alsijil.view_grouproles_rule",
        },
      },
      {
        path: "group_roles/create/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.createGroupRole",
      },
      {
        path: "group_roles/:pk(\\d+)/edit/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.editGroupRole",
      },
      {
        path: "group_roles/:pk(\\d+)/delete/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.deleteGroupRole",
      },
      {
        path: "groups/:pk(\\d+)/group_roles/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.assignedGroupRoles",
      },
      {
        path: "groups/:pk(\\d+)/group_roles/assign/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.assignGroupRole",
      },
      {
        path: "groups/:pk(\\d+)/group_roles/:role_pk(\\d+)/assign/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.assignGroupRoleByRolePK",
      },
      {
        path: "group_roles/assignments/:pk(\\d+)/edit/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.editGroupRoleAssignment",
      },
      {
        path: "group_roles/assignments/:pk(\\d+)/stop/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.stopGroupRoleAssignment",
      },
      {
        path: "group_roles/assignments/:pk(\\d+)/delete/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.deleteGroupRoleAssignment",
      },
      {
        path: "group_roles/assignments/assign/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.assignGroupRoleMultiple",
        meta: {
          inMenu: true,
          titleKey: "alsijil.group_roles.menu_title_assign",
          icon: "mdi-clipboard-account-outline",
          permission: "alsijil.assign_grouprole_for_multiple_rule",
        },
      },
      {
        path: "all/",
        component: () => import("aleksis.core/components/LegacyBaseTemplate.vue"),
        name: "alsijil.allRegisterObjects",
        meta: {
          inMenu: true,
          titleKey: "alsijil.all_lessons.menu_title",
          icon: "mdi-format-list-text",
          permission: "alsijil.view_register_objects_list_rule",
        },
      },
    ],
  };
